*********** Replication file for Thad Dunning and Janhavi Nilekani, 
*********** "Ethnic Quotas and Political Mobilization: Caste, Parties, and Distribution in Indian Village Councils"
*********** American Political Science Review, forthcoming.

**** This file conducts analysis on merged data set containing survey data from all three states (Karnataka, Rajasthan, and Bihar), 
**** as well as certain files for individual states
**** There are separate survey instruments and datasets for citizens and for panchayat presidents/members
**** Question numbers do not correspond across the survey instruments for the three states,
**** So any auxiliary analysis should be performed state-by-state while consulting the survey instrument for each state, or new merged files should be created
**** The various merged files in the replication archive were created for different purposes (e.g., analysis of the survey-experimental data, 
**** or analysis of panchayat presidents/members data)

clear

set mem 32m

* Change the current directory to the folder where all the replication data are stored using Stata's [cd "filename"] command.  In our case this is :

cd "/Users/td244/Dropbox/Folders_New_Mac/Research/EthnicPolitics/India_panchayats/Paper drafts/Dunning and Nilekani/APSR submission/Final Replication Files_Dunning and Nilekani_APSR/"

************** The following code generates descriptive statistics discussed in the text of section 2 of the paper

use "Dunning and Nilekani_citizen__merged_including census panchayat wise.dta"

* from the citizens' surveys

tab q28 if Bihar==1
tab q27 if Rajasthan==1
tab q31 if Rajasthan==1
tab q32 if Bihar==1
gen preshelp_benefit=.
replace preshelp_benefit=0 if (q28==1&Bihar==1&(q32>0|q32<9)&q32!=1)|(q27==1&Rajasthan==1&(q31>0&q31<9)&q31!=1)
replace preshelp_benefit=1 if (q28==1&Bihar==1&q32==1)|(q27==1&Rajasthan==1&q31==1)
sum preshelp
sum preshelp if Rajasthan==1
sum preshelp if Bihar==1
clear

* from president/members surveys

* Who decides MGNREGA projects and mate--Bihar

use "Bihar/sarpanch data_bihar_cleaned.dta"
tab q12_a if q2==2
tab q12_b if q2==2
clear

* Who decides MGNREGA projects and mate--Rajasthan

use "Rajasthan/sarpanch data_rajasthan_cleaned.dta"
tab q12_a if q2==2
tab q12_b if q2==2

* Figures in text come from pooling Bihar and Rajasthan data, e.g.:
* President decides MGNREGA projects: (149+82)/559=0.41
* Secretary decides MGNREGA projects: (44+29)/559=0.13
* Majority vote decides MGNREGA projects: (84+29)/559=0.20
* Gram Sabha decides MGNREGA projects: (49+66)/559=0.21
* President decides MGNREGA mate: (82+140)/527=0.42

clear

***************  TABLE II -- BALANCE TESTS

use "Bihar Rajasthan Karnataka Merged_FOR BALANCE TESTS.dta"

ttest P_ILL, by(scst_reserved_current) unequal
ttest MARGWORK_P, by(scst_reserved_current) unequal
ttest No_HH, by(scst_reserved_current) unequal
ttest MAIN_AL_P, by(scst_reserved_current) unequal
ttest MAIN_CL_P, by(scst_reserved_current) unequal
ttest NON_WORK_F, by(scst_reserved_current) unequal
ttest P_SC, by(scst_reserved_current) unequal
ttest P_ST, by(scst_reserved_current) unequal

* F-statistic from regression of treatment assignment on covariates is insignificant
regress scst_reserved_current P_ILL MARGWORK_P No_HH MAIN_AL_P MAIN_CL_P NON_WORK_F P_SC P_ST
* No households has fewer observations due to missing data so try also without:
regress scst_reserved_current P_ILL MARGWORK_P MAIN_AL_P MAIN_CL_P NON_WORK_F P_SC P_ST
clear

***************************** SECTION III

************* TABLE III: Analysis of effect of scst reservation

**** FIRST SET OF COlUMNS, FOR SC/ST CITIZENS
**** ANALYSIS BY WEIGHTED CLUSTER MEANS (WEIGHTING BY SC/ST PROPORTION USING CENSUS DATA)

* Here we estimate average causal effects by aggegating individual survey data to the level of treatment assignment (the village council) 
* The data set already contains data at the level of cluster (village council) means
* We need to weight the clusters by a measure of cluster size
* The code below does the trick

use "CLUSTER_MEANS_citizen_Karnataka_Bihar_Rajasthan_merged.dta"

* The code below gives the first row of Table III
sum P_SCST if scst_reserved_current==1&ave_jobbenefit01!=.
sum P_SCST if scst_reserved_current==0&ave_jobbenefit01!=.
* note that we are weighting by the SC/ST population size in the entire village, as recorded in the census
* So we need to divide by the number of panchayats in the treatment group (or control group), times the average SC/ST population size
* then, we still need to multiply by the number of panchayats
* This is equivalent to just dividing by the average SCST population size, since the number of panchayats in the treatment group cancels in the numerator and denominator:
gen weighted_jobbenefit01=.
replace weighted_jobbenefit01=(P_SCST)*(ave_jobbenefit01)/(1634.74) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_jobbenefit01=(P_SCST)*(ave_jobbenefit01)/(1673.38) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_jobbenefit01, by(scst_reserved_current) unequal


* Now we do the same for each of the other outcome variables in Table III, using the SC and ST Citizens data

sum P_SCST if scst_reserved_current==1&ave_MGNREGAben!=.
sum P_SCST if scst_reserved_current==0&ave_MGNREGAben!=.
gen weighted_MGNREGAben=.
replace weighted_MGNREGAben=(P_SCST)*(ave_MGNREGAben)/(1655.50) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_MGNREGAben=(P_SCST)*(ave_MGNREGAben)/(1721.67) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_MGNREGAben, by(scst_reserved_current) unequal

sum P_SCST if scst_reserved_current==1&ave_benefit_any!=.
sum P_SCST if scst_reserved_current==0&ave_benefit_any!=.
gen weighted_benefit_any=.
replace weighted_benefit_any=(P_SCST)*(ave_benefit_any)/(1655.50) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_benefit_any=(P_SCST)*(ave_benefit_any)/(1721.67) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_benefit_any, by(scst_reserved_current) unequal

sum P_SCST if scst_reserved_current==1&ave_scst_effective!=.
sum P_SCST if scst_reserved_current==0&ave_scst_effective!=.
gen weighted_scst_effective=.
replace weighted_scst_effective=(P_SCST)*(ave_scst_effective)/(1639.50) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_scst_effective=(P_SCST)*(ave_scst_effective)/(1639.34) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_scst_effective, by(scst_reserved_current) unequal

sum P_SCST if scst_reserved_current==1&ave_scst_influential!=.
sum P_SCST if scst_reserved_current==0&ave_scst_influential!=.
gen weighted_scst_influential=.
replace weighted_scst_influential=(P_SCST)*(ave_scst_influential)/(1639.50) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_scst_influential=(P_SCST)*(ave_scst_influential)/(1639.34) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_scst_influential, by(scst_reserved_current) unequal

sum P_SCST if scst_reserved_current==1&ave_scst_priority!=.
sum P_SCST if scst_reserved_current==0&ave_scst_priority!=.
gen weighted_scst_priority=.
replace weighted_scst_priority=(P_SCST)*(ave_scst_priority)/(1632.12) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_scst_priority=(P_SCST)*(ave_scst_priority)/(1639.42) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_scst_priority, by(scst_reserved_current) unequal

sum P_SCST if scst_reserved_current==1&ave_samepriority!=.
sum P_SCST if scst_reserved_current==0&ave_samepriority!=.
gen weighted_samepriority=.
replace weighted_samepriority=(P_SCST)*(ave_samepriority)/(1646.59) if scst_reserved_current==1&ave_jobbenefit01!=.
replace weighted_samepriority=(P_SCST)*(ave_samepriority)/(1714.69) if scst_reserved_current==0&ave_jobbenefit01!=.
ttest weighted_samepriority, by(scst_reserved_current) unequal

clear

**** SECOND SET OF COlUMNS, FOR MEMBERS/PRESIDENTS

* cluster-mean analysis

use "Sarpanch_Karnataka Bihar Rajasthan merged_cluster mean level.dta"

ttest scst_needseffectivektka_mean if scstrespondent==1, by(scst_reserved_current) unequal
ttest scstinfluence_mean, by(scst_reserved_current) unequal
ttest scstpriority_mean, by(scst_reserved_current) unequal
ttest samepriority_mean, by(scst_reserved_current) unequal

clear



****************** TABLE IV, FISCAL OUTCOMES 

**** column 1, own study group

use "Karnataka Bihar Rajasthan merged_FISCAL OUTCOMES.dta"

ttest Ashraya, by(scst_reserved_current) unequal
ttest IAY if IAY<6750001, by(scst_reserved_current) unequal
ttest Ambedkar, by(scst_reserved_current) unequal
ttest MGNREGA if MGNREGA<8700001, by(scst_reserved_current) unequal

clear

**** column 2, Karnataka Statewide Study Group

* There are three datasets with data for the Karnataka Statewide Study Group: RDPR Data, Gram Swaraj 0506 (2005-2006) data, and Gram Swaraj 0607 (2006-2007) data.
*There are two variables for testing,and in both there are 715 GPs reserved for SC/ST, and 715 which are not. 
*In 'reserved', 1=Reserved (treatment), 0=unreserved. 
*In 'reservedttest', 0=Reserved, 1=Unreserved, this is done so that the sign of the Stata output is correct for the difference in means
*All ttests below use "reservedttest"

* Change to "Karnataka" sub-directory:

* Change the current directory to the folder where all the replication data are stored using Stata's [cd "filename"] command.  In our case this is :

cd "/Users/td244/Dropbox/Folders_New_Mac/Research/EthnicPolitics/India_panchayats/Paper drafts/Dunning and Nilekani/APSR submission/Final APSR submission/Replication files/Karnataka"


*Gram Swaraj Data, 2006-2007:

use "Gram Swaraj Data 0607.dta"

ttest sss_ashray_exp, by(reservedttest) unequal 
ttest css_iay_exp, by(reservedttest) unequal
ttest sss_amb_hous_exp, by(reservedttest) unequal
ttest css_nregs_exp, by(reservedttest) unequal

clear

* RDPR data, April-September 2006:

use "RDPR data.dta"

ttest total_water_p3, by(reservedttest) unequal
ttest latr_ach_p3, by(reservedttest) unequal
ttest comlatr_ach_p3, by(reservedttest) unequal

clear

******************** Additional analyses on Karnataka Statewide Study Group  mentioned in text (the 286 tests)

* Within the RDPR dataset, these commands provide output in Stata 11 for the 108 RDPR test (27 variables over 4 time periods). These appear as the 27 tests for period 1 (p1), followed by period 2 (p2), etc
* Note that in earlier versions like Stata 9, must use individual ttest command instead

use "RDPR data.dta"

estpost ttest gpmeetings_p1 gpdecisions_p1 gsmeetings_p1 gsdecisions_p1 tot_borewell_p1 unused_borewell_p1 maintain_borewell_p1 tot_miniwater_p1 unused_miniwater_p1 maintain_miniwater_p1 tot_piped_p1 unused_piped_p1 maintain_piped_p1 total_water_p1 wr_demand_p1 wr_collection_p1 latr_ach_p1 comlatr_ach_p1 prev_demand_p1 curr_demand_p1 tot_demand_p1 p1_coll_p1 p2_coll_p1 tot_coll_p1 prev_bal_p1 curr_bal_p1 tot_bal_p1 gpmeetings_p2 gpdecisions_p2 gsmeetings_p2 gsdecisions_p2 tot_borewell_p2 unused_borewell_p2 maintain_borewell_p2 tot_miniwater_p2 unused_miniwater_p2 maintain_miniwater_p2 tot_piped_p2 unused_piped_p2 maintain_piped_p2 total_water_p2 wr_demand_p2 wr_collection_p2 latr_ach_p2 comlatr_ach_p2 prev_demand_p2 curr_demand_p2 tot_demand_p2 p1_coll_p2 p2_coll_p2 tot_coll_p2 prev_bal_p2 curr_bal_p2 tot_bal_p2 gpmeetings_p3 gpdecisions_p3 gsmeetings_p3 gsdecisions_p3 tot_borewell_p3 unused_borewell_p3 maintain_borewell_p3 tot_miniwater_p3 unused_miniwater_p3 maintain_miniwater_p3 tot_piped_p3 unused_piped_p3 maintain_piped_p3 total_water_p3 wr_demand_p3 wr_collection_p3 latr_ach_p3 comlatr_ach_p3 prev_demand_p3 curr_demand_p3 tot_demand_p3 p1_coll_p3 p2_coll_p3 tot_coll_p3 prev_bal_p3 curr_bal_p3 tot_bal_p3 gpmeetings_p4 gpdecisions_p4 gsmeetings_p4 gsdecisions_p4 tot_borewell_p4 unused_borewell_p4 maintain_borewell_p4 tot_miniwater_p4 unused_miniwater_p4 maintain_miniwater_p4 tot_piped_p4 unused_piped_p4 maintain_piped_p4 total_water_p4 wr_demand_p4 wr_collection_p4 latr_ach_p4 comlatr_ach_p4 prev_demand_p4 curr_demand_p4 tot_demand_p4 p1_coll_p4 p2_coll_p4 tot_coll_p4 prev_bal_p4 curr_bal_p4 tot_bal_p4, by(reservedttest)
esttab, wide se

clear

*Within the GramSwaraj0506 and GramSwaraj 0607 datasets, the following commands run the 89 ttests. The code is identical in both datasets.

use "Gram Swaraj Data 0607.dta"

estpost ttest open_bal grant_in_aid taxes nontaxes total_osr total_revenue expenditure closingbalance property_tax other_directtaxes special_water_tax general_tax license_fees other_fees gp_asset_incomes other_nontax grand_osr sss_section206 sss_dev_gran sss_nir_kar sss_ashray sss_sub_tot css_finance css_iay css_mws css_sgry css_sub_total sss_sgy sss_mnk sss_library sss_amb_hous sss_forest sss_ksg sss_nbn sss_naxal sss_mdm sss_gram_swaraj css_nregs css_tot_sani css_swajala css_waterdev css_con_edu css_sgsy css_pmgy css_jnirmal css_j_rak css_bh_nk css_drin_maint other_other_schem other_sub_total gran_total_all_scheme gen_adm_exp pub_proc_exp develop_exp pub_hea_exp civic_exp educ_exp adv_exp css_finan_exp sss_dev_grnt_exp sss_dev_gran_exp css_iay_exp css_rur_water_exp sss_ashray_exp css_sgry_exp sss_sgy_exp sss_mnk_exp sss_library_exp sss_amb_hous_exp sss_forest_exp sss_ksg_exp sss_nbn_exp sss_naxal_exp sss_mdm_exp sss_gram_swaraj_exp css_nregs_exp css_tot_sani_exp css_swajala_exp css_waterdev_exp css_con_edu_exp css_sgsy_exp css_pmgy_exp css_jnirmal_exp css_j_rak_exp css_bh_nk_exp css_rur_wat_exp other_other_exp other_exp gran_tot_exp, by(reservedttest)
esttab, wide se

clear

****************** TABLE V,  PARTY ANALYSIS

* for this analysis, we use a merged file combining citizens' data with data on the president's (Sarpanch's) party merged from the file

* Change the current directory back to the folder with the main replication data

cd "/Users/td244/Dropbox/Folders_New_Mac/Research/EthnicPolitics/India_panchayats/Paper drafts/Dunning and Nilekani/APSR submission/Final APSR submission/Replication files/"

use "citizen_Karnataka_Bihar_Rajasthan_merged_including census panchayat wise_TRIAL WITH SARPANCH PARTY DATA.dta"

* SHARING GP PRESIDENT'S PARTY AND RECEIPT OF JOB/BENEFIT

* The proportion of citizens who share the president's party varies by state, as does the baseline level of benefit receipt.  
* Pooling across states without accounting for this variation in "treatment assignment" proportions leads to a version of Simpson's Paradox (relationships between
* subgroups can be reversed when aggregated)

* In the analysis that produces Table V, we weight the within-state estimates as follows:

by State: sum memberpresparty

* Analysis by state (these are also reported in the online appendix)

* Job benefit

ttest jobbenefit0_1 if Karnataka==1, by(memberpresparty)
ttest jobbenefit0_1 if Rajasthan==1, by(memberpresparty)
ttest jobbenefit0_1 if Bihar==1, by(memberpresparty)

* Weights
* respondents Karnataka: 1828
* respondents Rajasthan: 2364
* respondents Bihar: 2625
* total respondents: 6817
* Karnataka weight: (1828/6817)=0.2682
* Rajasthan weight: (2364/6817)=0.3468
* Bihar weight: (2625/6817)=0.3851

* Karnataka--Does not share members party: .4342022 (se .0125012)
* Rajasthan--Does not share members party: .0869565 (se .0068319)
* Bihar--Does not share members party: .0514124 (se .0052506)

* Karnataka: Shares members party .5490196 (se .0312217)
* Rajasthan: Shares members party .1178248 (se .0125399)
* Bihar: Shares members party .0748538 (se .009005)

* estimate ATE is weighted average estimated ATE across these blocks (states)
* estimated treatment group outcome is weighted average of treatment group estimates across states
* treatment: (0.2682)(.5490196) + (0.3468)(.1178248) + (0.3851)(.0748538) = 0.21693489574
* treatment group se: sqrt(((0.2682)^2)*((.0312217)^2) + ((0.3468)^2)*((.0125399)^2) + ((0.3851)^2)((.009005)^2)) = 0.01005

* control: (0.2682)(.4342022) + (0.3468)(.0869565) + (0.3851)(.0514124) = 0.16640845948
* control group se: sqrt(((0.2682)^2)*((.0125012)^2) + ((0.3468)^2)*((.0068319)^2) + ((0.3851)^2)((.0052506)^2)) = 0.004576408976936

* difference of means: 0.21693489574 - 0.16640845948 = 0.05052643626
* se for difference of means: sqrt((0.01005)^2 + (0.004576408976936)^2) = 0.011042917147392730764

* The final six commented lines are reported on the first row of Table V


** SC/ST respondents only, job benefit


ttest jobbenefit0_1 if Karnataka==1&scstrespondent==1, by(memberpresparty)
ttest jobbenefit0_1 if Rajasthan==1&scstrespondent==1, by(memberpresparty)
ttest jobbenefit0_1 if Bihar==1&scstrespondent==1, by(memberpresparty)

* Weights:
* respondents Karnataka: 910
* respondents Rajasthan: 640
* respondents Bihar: 557
* total respondents: 910 + 640 + 557 = 2107
* Karnataka weight: (910/2107)=0.43189
* Rajasthan weight: (640/2107)=0.30375
* Bihar weight: (557/2107)=0.26436

* Karnataka--Does not share members party: .4968072 (se .0178796)
* Rajasthan--Does not share members party: .0847826 (se .013002) 
* Bihar--Does not share members party: .0861111 (se .0148057)

* Karnataka: Shares members party .5748031 (se .0440422) 
* Rajasthan: Shares members party .0944444 (se .0218584)
* Bihar: Shares members party .1015228 (se .0215728)

* weighted averages
* treatment: (0.43189)(.5748031) + (0.30375)(.0944444) + (0.26436)(.1015228) = 0.303777764767
* treatment group se: sqrt(((0.43189)^2)*((.0440422)^2) + ((0.30375)^2)*((.0218584)^2) + ((0.26436)^2)((.0215728)^2)) = 0.02093848067314

* control: (0.43189)(.4968072) + (0.30375)(.0847826) + (0.26436)(.0861111) = 0.263083106754
* control group se: sqrt(((0.43189)^2)*((.0178796)^2) + ((0.30375)^2)*((.013002)^2) + ((0.26436)^2)((.0148057)^2)) = 0.00951560262007

* difference of means: 0.303777764767 - 0.263083106754 = 0.040694658013
* se for difference of means: sqrt((0.02093848067314)^2 + (0.00951560262007)^2) = 0.02299927533907406302


** MGNREGA benefits

ttest MGNREGAben if Rajasthan==1, by(memberpresparty)
ttest MGNREGAben if Bihar==1, by(memberpresparty)

* Weights
* respondents Rajasthan 2370
* respondents Bihar: 2640
* total respondents: 2370 + 2640 = 5010
* Rajasthan weight: (2370/5010) = 0.47305389221557
* Bihar weight: (2640/5010) = 0.52694610778443

* Rajasthan--Does not share members party: .2909836 (se .0109937)
* Bihar--Does not share members party: .0797753 (se .0064238)

* Rajasthan: Shares members party .3761329 (se .0188415)
* Bihar: Shares members party .100 (se .0102359)

* weighted averages
* treatment:  (0.47305)(.3761329) + (0.526946)(.100) = 0.230624268345
* treatment group se: sqrt(((0.47305)^2)*((.0188415)^2) + ((0.526946)^2)((.0102359)^2)) = 0.01041795469445

* control:  (0.47305)(.2909836) + (0.526946)(.0797753) = 0.1796870672138
* control group se: sqrt(((0.47305)^2)*((.0109937)^2) + ((0.526946)^2)((.0064238)^2)) = 0.006205168980606

* difference of means: 0.230624268345 - 0.1796870672138 = 0.0509372011312
* se for difference of means: sqrt((0.01041795469445)^2 + (0.006205168980606)^2) = 0.012125918608232850004


** Any benefit 

ttest benefit_any if Rajasthan==1, by(memberpresparty)
ttest benefit_any if Bihar==1, by(memberpresparty)

* Weights
* respondents Rajasthan 2370
* respondents Bihar: 2640
* total respondents: 2370 + 2640 = 5010
* Rajasthan weight: (2370/5010) = 0.47305389221557
* Bihar weight: (2640/5010) = 0.52694610778443

* Rajasthan--Does not share members party: .5603044 (se .0120135) 
* Bihar--Does not share members party: .6353933 (se .0114116)

* Rajasthan: Shares members party .5996979 (se .0190572)
* Bihar: Shares members party .6604651 (se .0161574)

* weighted averages
* treatment:  (0.47305)(.5996979 ) + (0.526946)(.6604651) = 0.6317165341796
* treatment group se: sqrt(((0.47305)^2)*((.0190572)^2) + ((0.526946)^2)((.0161574)^2)) = 0.0123999955569

* control:  (0.47305)(.5603044) + (0.526946)(.6353933) = 0.5998699542818
* control group se: sqrt(((0.47305)^2)*((.0120135)^2) + ((0.526946)^2)((.0114116)^2)) = 0.00827381848713

* difference of means: 0.6317165341796 - 0.5998699542818 = 0.0318465798978
* se for difference of means: sqrt((0.0123999955569)^2 + (0.00827381848713)^2) = 0.01490690987995546658

** Same priority

ttest samepriority if Rajasthan==1, by(memberpresparty)
ttest samepriority if Bihar==1, by(memberpresparty)

* Weights
* respondents Rajasthan 2139
* respondents Bihar: 2210
* total respondents: 2139 + 2210 = 4349
* Rajasthan weight: (2139/4349) = 0.49183720395493
* Bihar weight: (2210/4349) = 0.50816279604507

* Rajasthan--Does not share members party: .1859264 (se .0098882)
* Bihar--Does not share members party: .2809365 (se .0116282)

* Rajasthan: Shares members party: .2338983 (se .0174421)
* Bihar: Shares members party: .2825175 (se .0168492)

* weighted averages
* treatment:  (0.49183720395493)(.2338983) + (0.50816279604507)(.2825175) = 0.25860476861347446734
* treatment group se: sqrt(((0.49183720395493)^2)*((.0174421)^2) + ((0.50816279604507)^2)((.0168492)^2)) = 0.01212038882359333075

* control:  (0.49183720395493)(.1859264) + (0.50816279604507)(.2809365) = 0.23420699806852170521
* control group se: sqrt(((0.49183720395493)^2)*((.0098882)^2) + ((0.50816279604507)^2)((.0116282)^2)) = 0.00765303934840770479

* difference of means: 0.25860476861347446734 - 0.23420699806852170521 = 0.02439777054495276213
* se for difference of means: sqrt((0.01212038882359333075)^2 + (0.00765303934840770479)^2) = 0.01433432371977704258290705

* t-ratio: (0.02439777054495276213/0.01433432371977704258290705) = 1.70205243176496695889766689026462


** Job benefit by close to party

ttest jobbenefit0_1 if Karnataka==1, by(closepresparty)
ttest jobbenefit0_1 if Rajasthan==1, by(closepresparty)
ttest jobbenefit0_1 if Bihar==1, by(closepresparty)

* Weights
* respondents Karnataka: 1828
* respondents Rajasthan: 2364
* respondents Bihar: 2625
* total respondents: 1828 + 2364 + 2625 = 6817
* Karnataka weight: (1828/6817)=0.2682
* Rajasthan weight: (2364/6817)=0.3468
* Bihar weight: (2625/6817)=0.3851

* Karnataka--Does not share members party: .4421864  (se .0131519)
* Rajasthan--Does not share members party: .0886347 (se .0076014)
* Bihar--Does not share members party: .0634076 (se .0053627) 

* Karnataka: Shares members party: .478803 (se .0249775)
* Rajasthan: Shares members party: .1056995 (se .0099024)
* Bihar: Shares members party: .0429338 (se .0085813)

* weighted averages
* treatment: (0.2682)(.478803) + (0.3468)(.1056995) + (0.3851)(.0429338) = 0.18160535758
* treatment group se: sqrt(((0.2682)^2)*((.0249775)^2) + ((0.3468)^2)*((.0099024)^2) + ((0.3851)^2)((.0085813)^2)) = 0.008221332591982

* control: (0.2682)(.4421864) + (0.3468)(.0886347) + (0.3851)(.0634076) = 0.1737511732
* control group se: sqrt(((0.2682)^2)*((.0131519)^2) + ((0.3468)^2)*((.0076014)^2) + ((0.3851)^2)((.0053627)^2)) = 0.004863789070516

* difference of means: 0.18160535758 - 0.1737511732 = 0.00785418438
* se for difference of means: sqrt((0.008221332591982)^2 + (0.004863789070516)^2) = 0.009552316667199447786

* t-ratio: 0.00785418438/0.009552316667199447786 = 0.822

clear

*********************** Analysis of scenario/sarpanch candidate experiment, by caste and party ties


**************** TABLE VI.A 

use "Bihar_Rajasthan_merged_for_experiments_replication_file.dta"

* note: this file combines data from Bihar and Rajasthan; because the question numbers differ in the questionnaires for those states, variables analyzed below are given common names
* before merging files from the two states.  Since other variables have different question numbers in the two states, they should not be analyzed using this file.
* For other variables, see the replication files for the respective states:
* "RAJASTHAN DATA CITIZEN_merged with SARPANCH and MLA party.dta" and "/Users/td244/Dropbox/Folders_New_Mac/Research/EthnicPolitics/india_panchayats/bihar/Bihar data/Bihar citizens_cleaned 15 may.dta

** effects of party membership and broad caste category on vote for candidate

ttest wouldvote_exper if samecastecombined_exp==1, by(sameparty_exp)
ttest wouldvote_exper  if samecastecombined_exp==0, by(sameparty_exp)
ttest wouldvote_exper  if sameparty_exp==1, by(samecastecombined_exp)
ttest wouldvote_exper  if sameparty_exp==0, by(samecastecombined_exp)
ttest wouldvote_exper  if ((sameparty_exp==1&samecastecombined_exp==1)|(sameparty_exp==0&samecastecombined_exp==0)), by(sameparty_exp)

** effects of party membership and narrow caste category on vote for candidate

ttest wouldvote_exper if samecaste_exp==1, by(sameparty_exp)
ttest wouldvote_exper if samecaste_exp==0, by(sameparty_exp)
ttest wouldvote_exper if sameparty_exp==1, by(samecaste_exp)
ttest wouldvote_exper if sameparty_exp==0, by(samecaste_exp)
ttest wouldvote_exper if ((sameparty_exp==1&samecaste_exp==1)|(sameparty_exp==0&samecaste_exp==0)), by(sameparty_exp)

** effects of party membership and jati on vote for candidate

ttest wouldvote_exper if samejati_exp==1, by(sameparty_exp)
ttest wouldvote_exper if samejati_exp==0, by(sameparty_exp)
ttest wouldvote_exper if sameparty_exp==1, by(samejati_exp)
ttest wouldvote_exper if sameparty_exp==0, by(samejati_exp)
ttest wouldvote_exper if ((sameparty_exp==1&samejati_exp==1)|(sameparty_exp==0&samejati==0)), by(sameparty_exp)

****************** TABLE VI.B

** effects of party closeness and broad caste category on vote for candidate

ttest wouldvote_exper if samecastecombined_exp==1, by(samepartyclose_exp)
ttest wouldvote_exper if samecastecombined_exp==0, by(samepartyclose_exp)
ttest wouldvote_exper if samepartyclose_exp==1, by(samecastecombined_exp)
ttest wouldvote_exper if samepartyclose_exp==0, by(samecastecombined_exp)
ttest wouldvote_exper if ((samepartyclose_exp==1&samecastecombined_exp==1)|(samepartyclose_exp==0&samecastecombined_exp==0)), by(samepartyclose_exp)

** effects of party closeness and narrow caste category on vote for candidate

ttest wouldvote_exper if samecaste_exp==1, by(samepartyclose_exp)
ttest wouldvote_exper if samecaste_exp==0, by(samepartyclose_exp)
ttest wouldvote_exper if samepartyclose_exp==1, by(samecaste_exp)
ttest wouldvote_exper if samepartyclose_exp==0, by(samecaste_exp)
ttest wouldvote_exper if ((samepartyclose_exp==1&samecaste_exp==1)|(samepartyclose_exp==0&samecaste_exp==0)), by(samepartyclose_exp)

** effects of party closeness and jati on vote intentions

ttest wouldvote_exper if samejati_exp==1, by(samepartyclose_exp)
ttest wouldvote_exper if samejati_exp==0, by(samepartyclose_exp)
ttest wouldvote_exper if samepartyclose_exp==1, by(samejati_exp)
ttest wouldvote_exper if samepartyclose_exp==0, by(samejati_exp)
ttest wouldvote_exper if ((samepartyclose_exp==1&samejati_exp==1)|(samepartyclose_exp==0&samejati==0)), by(samepartyclose_exp)

***************** TABLE VII.A

** Effects of party membership and broad caste category on combined jobs/benefits measure

ttest jobbenefit_exper if samecastecombined_exp==1, by(sameparty_exp)
ttest jobbenefit_exper  if samecastecombined_exp==0, by(sameparty_exp)
ttest jobbenefit_exper  if sameparty_exp==1, by(samecastecombined_exp)
ttest jobbenefit_exper  if sameparty_exp==0, by(samecastecombined_exp)
ttest jobbenefit_exper if ((sameparty_exp==1&samecastecombined_exp==1)|(sameparty_exp==0&samecastecombined_exp==0)), by(sameparty_exp)

** effects of party membership and narrow caste category on combined jobs/benefits measure

ttest jobbenefit_exper if samecaste_exp==1, by(sameparty_exp)
ttest jobbenefit_exper if samecaste_exp==0, by(sameparty_exp)
ttest jobbenefit_exper if sameparty_exp==1, by(samecaste_exp)
ttest jobbenefit_exper if sameparty_exp==0, by(samecaste_exp)
ttest jobbenefit_exper if ((sameparty_exp==1&samecaste_exp==1)|(sameparty_exp==0&samecaste_exp==0)), by(sameparty_exp)

** effects of party membership and jati on combined jobs/benefits measure

ttest jobbenefit_exper if samejati_exp==1, by(sameparty_exp)
ttest jobbenefit_exper if samejati_exp==0, by(sameparty_exp)
ttest jobbenefit_exper if sameparty_exp==1, by(samejati_exp)
ttest jobbenefit_exper if sameparty_exp==0, by(samejati_exp)
ttest jobbenefit_exper if ((sameparty_exp==1&samejati_exp==1)|(sameparty_exp==0&samejati==0)), by(sameparty_exp)



***************** TABLE VII.B

** effects of party closeness and broad caste category on combined jobs/benefits measure

ttest jobbenefit_exper if samecastecombined_exp==1, by(samepartyclose_exp)
ttest jobbenefit_exper if samecastecombined_exp==0, by(samepartyclose_exp)
ttest jobbenefit_exper if samepartyclose_exp==1, by(samecastecombined_exp)
ttest jobbenefit_exper if samepartyclose_exp==0, by(samecastecombined_exp)
ttest jobbenefit_exper if ((samepartyclose_exp==1&samecastecombined_exp==1)|(samepartyclose_exp==0&samecastecombined_exp==0)), by(samepartyclose_exp)

** effects of party closeness and narrow caste category on combined jobs/benefits measure

ttest jobbenefit_exper if samecaste_exp==1, by(samepartyclose_exp)
ttest jobbenefit_exper if samecaste_exp==0, by(samepartyclose_exp)
ttest jobbenefit_exper if samepartyclose_exp==1, by(samecaste_exp)
ttest jobbenefit_exper if samepartyclose_exp==0, by(samecaste_exp)
ttest jobbenefit_exper if ((samepartyclose_exp==1&samecaste_exp==1)|(samepartyclose_exp==0&samecaste_exp==0)), by(samepartyclose_exp)

** effects of party closeness and jati on combined jobs/benefits measure

ttest jobbenefit_exper if samejati_exp==1, by(samepartyclose_exp)
ttest jobbenefit_exper if samejati_exp==0, by(samepartyclose_exp)
ttest jobbenefit_exper if samepartyclose_exp==1, by(samejati_exp)
ttest jobbenefit_exper if samepartyclose_exp==0, by(samejati_exp)
ttest jobbenefit_exper if ((samepartyclose_exp==1&samejati_exp==1)|(samepartyclose_exp==0&samejati==0)), by(samepartyclose_exp)

clear



******* ONLINE APPENDIX

************ TABLE A2 (BALANCE TESTS)

use "Bihar Rajasthan Karnataka Merged_FOR BALANCE TESTS.dta"

ttest NON_WORK_M, by(scst_reserved_current) unequal
ttest MAIN_CL_F, by(scst_reserved_current) unequal
ttest MAIN_HH_P, by(scst_reserved_current) unequal
ttest MARG_AL_M, by(scst_reserved_current) unequal
ttest TOT_WORK_P, by(scst_reserved_current) unequal
ttest TOT_P, by(scst_reserved_current) unequal
ttest MAIN_OT_F, by(scst_reserved_current) unequal
ttest P_06, by(scst_reserved_current) unequal
ttest F_ILL, by(scst_reserved_current) unequal
ttest prop_sc, by(scst_reserved_current) unequal
ttest prop_st, by(scst_reserved_current) unequal


*** Table A3

ttest P_ILL if Karnataka==1, by(scst_reserved_current) unequal
ttest TOT_WORK_P if Karnataka==1, by(scst_reserved_current) unequal
ttest MARGWORK_P if Karnataka==1, by(scst_reserved_current) unequal
ttest No_HH if Karnataka==1, by(scst_reserved_current) unequal
ttest TOT_P if Karnataka==1, by(scst_reserved_current) unequal
ttest TOT_M if Karnataka==1, by(scst_reserved_current) unequal
ttest MAIN_AL_P if Karnataka==1, by(scst_reserved_current) unequal
ttest MAIN_CL_P if Karnataka==1, by(scst_reserved_current) unequal
ttest P_06 if Karnataka==1, by(scst_reserved_current) unequal
ttest NON_WORK_F if Karnataka==1, by(scst_reserved_current) unequal
ttest P_SC if Karnataka==1, by(scst_reserved_current) unequal
ttest P_ST if Karnataka==1, by(scst_reserved_current) unequal

*** Table A4

ttest P_ILL if Rajasthan==1, by(scst_reserved_current) unequal
ttest TOT_WORK_P if Rajasthan==1, by(scst_reserved_current) unequal
ttest MARGWORK_P if Rajasthan==1, by(scst_reserved_current) unequal
* No_HH is missing for Rajasthan, it was not in original census file
ttest TOT_P if Rajasthan==1, by(scst_reserved_current) unequal
ttest TOT_M if Rajasthan==1, by(scst_reserved_current) unequal
ttest MAIN_AL_P if Rajasthan==1, by(scst_reserved_current) unequal
ttest MAIN_CL_P if Rajasthan==1, by(scst_reserved_current) unequal
ttest P_06 if Rajasthan==1, by(scst_reserved_current) unequal
ttest NON_WORK_F if Rajasthan==1, by(scst_reserved_current) unequal
ttest P_SC if Rajasthan==1, by(scst_reserved_current) unequal
ttest P_ST if Rajasthan==1, by(scst_reserved_current) unequal

*** Table A5

ttest P_ILL if Bihar==1, by(scst_reserved_current) unequal
ttest TOT_WORK_P if Bihar==1, by(scst_reserved_current) unequal
ttest MARGWORK_P if Bihar==1, by(scst_reserved_current) unequal
ttest No_HH if Bihar==1, by(scst_reserved_current) unequal
ttest TOT_P if Bihar==1, by(scst_reserved_current) unequal
ttest TOT_M if Bihar==1, by(scst_reserved_current) unequal
ttest MAIN_AL_P if Bihar==1, by(scst_reserved_current) unequal
ttest MAIN_CL_P if Bihar==1, by(scst_reserved_current) unequal
ttest P_06 if Bihar==1, by(scst_reserved_current) unequal
ttest NON_WORK_F if Bihar==1, by(scst_reserved_current) unequal
ttest P_SC if Bihar==1, by(scst_reserved_current) unequal
ttest P_ST if Bihar==1, by(scst_reserved_current) unequal

clear

***** Table A6: Karnataka Large-N Study Group

* tests to assess balance on pre-treatment covariates across the reserved and unreserved groups. 
* There are three datasets: RDPR Data, Gram Swaraj 0506 (2005-2006) data, and Gram Swaraj 0607 data.
* The following ttests can be run in any of the three datasets in Stata 11.  

* There are two variables for testing,and in both there are 715 GPs reserved for SC/ST, and 715 which are not. 
* In 'reserved', 1=Reserved (treatment), 0=unreserved. 
* In 'reservedttest', 0=Reserved, 1=Unreserved, this is done so that the sign of the Stata output is correct for the difference in means
* All ttests below use "reservedttest"

* E.g., in the RDPR data:

use "RDPR data.dta"

ttest p_ill, by(reservedttest) 
ttest tot_work_p, by(reservedttest) 
ttest margwork_p, by(reservedttest) 
ttest no_hh, by(reservedttest) 
ttest tot_p, by(reservedttest) 
ttest tot_m, by(reservedttest) 
ttest main_al_p, by(reservedttest) 
ttest main_cl_p, by(reservedttest) 
ttest p_06, by(reservedttest) 
ttest non_work_f, by(reservedttest) 
ttest tot_p, by(reservedttest) 
ttest agedistribution, by(reservedttest) 
ttest sexratio, by(reservedttest) 
ttest childsexratio, by(reservedttest)
ttest literacyrate, by(reservedttest) 
ttest tot_work_p, by(reservedttest) 
ttest stpercentage, by(reservedttest) 
ttest scpercentage, by(reservedttest)

clear

*************** EXTERNAL VALIDITY

**** Table A7--Rajasthan, Study Group versus universe of panchayats in the state

* Study group
use "Bihar Rajasthan Karnataka Merged_FOR BALANCE TESTS.dta"

sum TOT_P if Rajasthan==1
sum P_SC if Rajasthan==1
sum P_ST if Rajasthan==1
sum P_LIT if Rajasthan==1
sum TOT_WORK_P if Rajasthan==1
sum MAIN_CL_P if Rajasthan==1
sum MAIN_AL_P if Rajasthan==1
sum MARGWORK_P if Rajasthan==1
sum NON_WORK_P if Rajasthan==1
sum F_06 if Rajasthan==1
sum F_ILL if Rajasthan==1

* Universe of panchayats in state
use "/Users/td244/Dropbox/Folders_New_Mac/Research/EthnicPolitics/India_panchayats/Rajasthan survey/Census data_Rajasthan/Rajasthan_ALL PANCHAYATS_census data.dta"

sum TOT_P
sum P_SC
sum P_ST
sum P_Lit
sum Tot_Work_P
sum Main_CL_P
sum Main_AL_P
sum Marg_Work_P
sum Non_Work_P
sum F_06
sum F_ILL
sum Area

* final column
gen diff_pop = 4814.4-4721.1
gen se_pop=(1960.9)/(sqrt(148))
gen diff_sc=(756.4-816.2)
gen se_sc=(491.2)/(sqrt(148))
gen diff_st=520.9-820.0
gen se_st=(544.3)/(sqrt(148))
gen diff_lit=2115.7-2098.0
gen se_lit=(1211.4)/(sqrt(148))
gen diff_emp=2239.0-2154.1
gen se_emp=(773.4)/(sqrt(148))
gen diff_main=1070.1-1005.5
gen se_main=(620.0)/(sqrt(148))
gen diff_mainag=91.3-102.4
gen se_mainag=(101.2)/(sqrt(148))
gen diff_margwork=588.1-645.1
gen se_margwork=(388.1)/(sqrt(148))
gen diff_nonwork=2606.0-2567.0
gen nonwork_se=(1276.9)/(sqrt(148))
gen diff_female06=453.3-447.1
gen female06_se=(198.5)/(sqrt(148))
gen diff_female_ill=1665.2-1591.2
gen female_ill_se=(571.3)/(sqrt(148))

sum diff_pop se_pop
sum diff_sc se_sc
sum diff_st se_st
sum diff_lit se_lit
sum diff_emp se_emp
sum diff_main se_main
sum diff_mainag se_mainag
sum diff_margwork se_margwork
sum diff_nonwork nonwork_se
sum diff_female06 female06_se
sum diff_female_ill female_ill_se

clear


**** Table A8--Karnataka, Study Group versus universe of panchayats in the state

use "Karnataka_Secretary Data_Final.dta"

sum scproportion 
sum no_hh 
sum tot_p 
sum tot_m 
sum tot_f 
sum p_06 
sum m_06 
sum f_06 
sum p_sc 
sum p_st 
sum p_ill 
sum tot_work_p 
sum margwork_p

clear

* Insert commands for average of councils in State of Karnataka, using RDPR/Gram Swaraj datasets  TO BE COMPLETED



****************  TABLE A9: DESCRIPTIVE STATISTICS

* Karnataka (first two columns) -- here we use sampling weights when estimating parameters for the whole population, to account for oversampling of SC/ST citizens in this state
* Note that survey weights are only needed for estimates in the whole population (first column of Table IV)
* They are not needed for estimating parameters for SC/ST citizens only

use "Karnataka_citizen_final_withpartyvars_v2.dta"

svyset [pweight=weight]

svy: mean jobbenefit0_1
estat sd
sum jobbenefit0_1 if scstrespondent==1

svy: mean SCSTinfluential 
estat sd
sum SCSTinfluential if scstrespondent==1

svy: mean PanchFavorsSCST
estat sd
sum PanchFavorsSCST if scstrespondent==1

svy: mean scsteffective_rescaled
estat sd
sum scsteffective_rescaled if scstrespondent==1

svy: mean favorcaste0_1
estat sd
sum favorcaste0_1 if scstrespondent==1 

svy: mean gramsabha0_1
estat sd
sum gramsabha0_1 if scstrespondent==1

svy: mean knowspresjati
estat sd
sum knowspresjati if scstrespondent==1 

svy: mean knowspresparty
estat sd
sum knowspresparty if scstrespondent==1 

clear

** Rajasthan and Bihar (third-sixth columns of Table A9)

use "citizen_Karnataka_Bihar_Rajasthan_merged_including census panchayat wise.dta"

* Received job or benefit
sum jobbenefit0_1 if Rajasthan==1
sum jobbenefit0_1 if Rajasthan==1&scstrespondent==1
sum jobbenefit0_1 if Bihar==1
sum jobbenefit0_1 if Bihar==1&scstrespondent==1
*MGNREGA beneficiary
sum MGNREGAben if Rajasthan==1
sum MGNREGAben if Rajasthan==1&scstrespondent==1
sum MGNREGAben if Bihar==1
sum MGNREGAben if Bihar==1&scstrespondent==1
* Beneficiary of any government scheme
sum benefit_any if Rajasthan==1
sum benefit_any if Rajasthan==1&scstrespondent==1
sum benefit_any if Bihar==1
sum benefit_any if Bihar==1&scstrespondent==1
* SC or ST have most influence over panchayat
sum scst_influential if Rajasthan==1
sum scst_influential if Rajasthan==1&scstrespondent==1
sum scst_influential if Bihar==1
sum scst_influential if Bihar==1&scstrespondent==1
* SC or ST receive priority from panchayat
sum scst_priority if Rajasthan==1
sum scst_priority if Rajasthan==1&scstrespondent==1
sum scst_priority if Bihar==1
sum scst_priority if Bihar==1&scstrespondent==1
* Council effectively serves SC/ST (1-7 scale)
sum scst_effective if Rajasthan==1
sum scst_effective if Rajasthan==1&scstrespondent==1
sum scst_effective if Bihar==1
sum scst_effective if Bihar==1&scstrespondent==1
* Respondent's priority is council's priority
sum samepriority if Rajasthan==1
sum samepriority if Rajasthan==1&scstrespondent==1
sum samepriority if Bihar==1
sum samepriority if Bihar==1&scstrespondent==1
* Presidents favor own caste or tribe in allocating benefits
sum favorcaste1_7 if Rajasthan==1
sum favorcaste1_7 if Rajasthan==1&scstrespondent==1
sum favorcaste1_7 if Bihar==1
sum favorcaste1_7 if Bihar==1&scstrespondent==1
* Presidents favor their own party in allocating benefits
sum favorparty1_7 if Rajasthan==1
sum favorparty1_7 if Rajasthan==1&scstrespondent==1
sum favorparty1_7 if Bihar==1
sum favorparty1_7 if Bihar==1&scstrespondent==1
* Presidents favor their own gender in allocating benefits
clear
use "RAJASTHAN DATA CITIZEN_merged with SARPANCH party_3.dta"
sum q57 if q57>0&q57<8
sum q57 if scstrespondent==1&q57>0&q57<8
clear
use "citizen_Karnataka_Bihar_Rajasthan_merged_including census panchayat wise.dta"
sum q58 if Bihar==1&q58>0&q58<8
sum q58 if Bihar==1&scstrespondent==1&q58>0&q58<8
* Knows president's caste (jati)
sum knowspresjati if Rajasthan==1
sum knowspresjati if Rajasthan==1&scstrespondent==1
sum knowspresjati if Bihar==1
sum knowspresjati if Bihar==1&scstrespondent==1
* Knows president's party
sum knowspresparty if Rajasthan==1
sum knowspresparty if Rajasthan==1&scstrespondent==1
sum knowspresparty if Bihar==1
sum knowspresparty if Bihar==1&scstrespondent==1

clear

** TABLE A10, DESCRIPTIVE STATISTICS WITH MEMBERS/PRESIDENTS DATA

* Karnataka, members and presidents 

use "Sarpanch_Karnataka_Bihar_Rajasthan_merged.dta"

sum scst_influence if Karnataka==1
sum scst_influence if Karnataka==1&scstrespondent==1
sum scst_influence if Rajasthan==1
sum scst_influence if Rajasthan==1&scstrespondent==1
sum scst_influence if Bihar==1
sum scst_influence if Bihar==1&scstrespondent==1

sum scst_priority if Karnataka==1
sum scst_priority if Karnataka==1&scstrespondent==1
sum scst_priority if Rajasthan==1
sum scst_priority if Rajasthan==1&scstrespondent==1
sum scst_priority if Bihar==1
sum scst_priority if Bihar==1&scstrespondent==1

sum scst_needseffective_ktka if Karnataka==1
sum scst_needseffective_ktka if Karnataka==1&scstrespondent==1

sum samepriority if Karnataka==1
sum samepriority  if Karnataka==1&scstrespondent==1
sum samepriority  if Rajasthan==1
sum samepriority  if Rajasthan==1&scstrespondent==1
sum samepriority  if Bihar==1
sum samepriority if Bihar==1&scstrespondent==1

sum favorcaste0_1 if Karnataka==1
sum favorcaste0_1 if Karnataka==1&scstrespondent==1
sum favorcaste1_7  if Rajasthan==1
sum favorcaste1_7  if Rajasthan==1&scstrespondent==1
sum favorcaste1_7  if Bihar==1
sum favorcaste1_7 if Bihar==1&scstrespondent==1

sum disagree_ben if Karnataka==1
sum disagree_ben if Karnataka==1&scstrespondent==1
sum disagree_ben  if Rajasthan==1
sum disagree_ben  if Rajasthan==1&scstrespondent==1
sum disagree_ben  if Bihar==1
sum disagree_ben if Bihar==1&scstrespondent==1

sum knowspresjati if Karnataka==1
sum knowspresjati if Karnataka==1&scstrespondent==1
sum knowspresjati if Rajasthan==1
sum knowspresjati if Rajasthan==1&scstrespondent==1
sum knowspresjati if Bihar==1
sum knowspresjati if Bihar==1&scstrespondent==1

sum knowspresparty if Karnataka==1
sum knowspresparty if Karnataka==1&scstrespondent==1
sum knowspresparty if Rajasthan==1
sum knowspresparty if Rajasthan==1&scstrespondent==1
sum knowspresparty if Bihar==1
sum knowspresparty if Bihar==1&scstrespondent==1


****************** CAUSAL EFFECTS OF QUOTAS

** TABLE A11

* Cluster mean analysis by state, citizens data, using SC/ST population proportions from census as weights

* now we are weighting by the SC population size in the entire village, as recorded in the census
* So we need to divide by the number of panchayats in the treatment group (or control group), times the average SC population size
* and we still need to multiply by the number of panchayats (See "Dunning and Nilekani_APSR Second Submission_Analysis.do" for further discussion)
* This is equivalent to just dividing by the average SC population size, since the number of panchayats in the treatment group cancels in the numerator and denominator
* for each test belo, we sum P_SC in the treatment and control groups to get the average SC population size, then generate the weighted cluster means
 
use "CLUSTER_MEANS_citizen_Karnataka_Bihar_Rajasthan_merged.dta"

* KARNATAKA

sum P_SC if scst_reserved_current==1&ave_jobbenefit01!=.&Karnataka==1
sum P_SC if scst_reserved_current==0&ave_jobbenefit01!=.&Karnataka==1
gen weighted_jobbenefit01_ktka=.
replace weighted_jobbenefit01_ktka=(P_SC)*(ave_jobbenefit01)/(1099.75) if scst_reserved_current==1&ave_jobbenefit01!=.&Karnataka==1
replace weighted_jobbenefit01_ktka=(P_SC)*(ave_jobbenefit01)/(1155.14) if scst_reserved_current==0&ave_jobbenefit01!=.&Karnataka==1
ttest weighted_jobbenefit01_ktka, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_effective!=.&Karnataka==1
sum numSCST if scst_reserved_current==0&ave_scst_effective!=.&Karnataka==1
gen weighted_scst_effective_ktka=.
replace weighted_scst_effective_ktka=(numSCST)*(79/384.02)*(ave_scst_effective) if scst_reserved_current==1&ave_scst_effective!=.&Karnataka==1
replace weighted_scst_effective_ktka=(numSCST)*(76/386)*(ave_scst_effective) if scst_reserved_current==0&ave_scst_effective!=.&Karnataka==1
ttest weighted_scst_effective_ktka, by(scst_reserved_current) unequal
* Note that effective question was only asked in 2nd phase of Karnataka surveys

sum numSCST if scst_reserved_current==1&ave_scst_influential!=.&Karnataka==1
sum numSCST if scst_reserved_current==0&ave_scst_influential!=.&Karnataka==1
gen weighted_scst_influential_ktka=.
replace weighted_scst_influential_ktka=(numSCST)*(74/358.974)*(ave_scst_influential) if scst_reserved_current==1&ave_scst_influential!=.&Karnataka==1
replace weighted_scst_influential_ktka=(numSCST)*(69/352.038)*(ave_scst_influential) if scst_reserved_current==0&ave_scst_influential!=.&Karnataka==1
ttest weighted_scst_influential_ktka, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_priority!=.&Karnataka==1
sum numSCST if scst_reserved_current==0&ave_scst_priority!=.&Karnataka==1
gen weighted_scst_priority_ktka=.
replace weighted_scst_priority_ktka=(numSCST)*(77/372.988)*(ave_scst_priority) if scst_reserved_current==1&ave_scst_priority!=.&Karnataka==1
replace weighted_scst_priority_ktka=(numSCST)*(76/386.004)*(ave_scst_priority) if scst_reserved_current==0&ave_scst_priority!=.&Karnataka==1
ttest weighted_scst_priority_ktka, by(scst_reserved_current) unequal

* RAJASTHAN

sum numSCST if scst_reserved_current==1&ave_jobbenefit01!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_jobbenefit01!=.&Rajasthan==1
gen weighted_jobbenefit01_raj=.
replace weighted_jobbenefit01_raj=(numSCST)*(66/328.0002)*(ave_jobbenefit01) if scst_reserved_current==1&ave_jobbenefit01!=.&Rajasthan==1
replace weighted_jobbenefit01_raj=(numSCST)*(66/314.0016)*(ave_jobbenefit01) if scst_reserved_current==0&ave_jobbenefit01!=.&Rajasthan==1
ttest weighted_jobbenefit01_raj, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_MGNREGAben!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_MGNREGAben!=.&Rajasthan==1
gen weighted_MGNREGAben_raj=.
replace weighted_MGNREGAben_raj=(numSCST)*(66/328.0002)*(ave_MGNREGAben) if scst_reserved_current==1&ave_MGNREGAben!=.&Rajasthan==1
replace weighted_MGNREGAben_raj=(numSCST)*(66/314.0016)*(ave_MGNREGAben) if scst_reserved_current==0&ave_MGNREGAben!=.&Rajasthan==1
ttest weighted_MGNREGAben_raj, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_benefit_any!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_benefit_any!=.&Rajasthan==1
gen weighted_benefit_any_raj=.
replace weighted_benefit_any_raj=(numSCST)*(66/328.0002)*(ave_benefit_any) if scst_reserved_current==1&ave_benefit_any!=.&Rajasthan==1
replace weighted_benefit_any_raj=(numSCST)*(66/314.0016)*(ave_benefit_any) if scst_reserved_current==0&ave_benefit_any!=.&Rajasthan==1
ttest weighted_benefit_any_raj, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_effective!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_scst_effective!=.&Rajasthan==1
gen weighted_scst_effective_raj=.
replace weighted_scst_effective_raj=(numSCST)*(66/328.0002)*(ave_scst_effective) if scst_reserved_current==1&ave_scst_effective!=.&Rajasthan==1
replace weighted_scst_effective_raj=(numSCST)*(66/314.0016)*(ave_scst_effective) if scst_reserved_current==0&ave_scst_effective!=.&Rajasthan==1
ttest weighted_scst_effective_raj, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_influential!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_scst_influential!=.&Rajasthan==1
gen weighted_scst_influential_raj=.
replace weighted_scst_influential_raj=(numSCST)*(65/327.015)*(ave_scst_influential) if scst_reserved_current==1&ave_scst_influential!=.&Rajasthan==1
replace weighted_scst_influential_raj=(numSCST)*(66/314.0016)*(ave_scst_influential) if scst_reserved_current==0&ave_scst_influential!=.&Rajasthan==1
ttest weighted_scst_influential_raj, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_priority!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_scst_priority!=.&Rajasthan==1
gen weighted_scst_priority_raj=.
replace weighted_scst_priority_raj=(numSCST)*(65/327.015)*(ave_scst_priority) if scst_reserved_current==1&ave_scst_priority!=.&Rajasthan==1
replace weighted_scst_priority_raj=(numSCST)*(66/314.0016)*(ave_scst_priority) if scst_reserved_current==0&ave_scst_priority!=.&Rajasthan==1
ttest weighted_scst_priority_raj, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_samepriority!=.&Rajasthan==1
sum numSCST if scst_reserved_current==0&ave_samepriority!=.&Rajasthan==1
gen weighted_samepriority_raj=.
replace weighted_samepriority_raj=(numSCST)*(66/328.0002)*(ave_samepriority) if scst_reserved_current==1&ave_samepriority!=.&Rajasthan==1
replace weighted_samepriority_raj=(numSCST)*(65/310.999)*(ave_samepriority) if scst_reserved_current==0&ave_samepriority!=.&Rajasthan==1
ttest weighted_samepriority_raj, by(scst_reserved_current) unequal

* BIHAR

sum numSCST if scst_reserved_current==1&ave_jobbenefit01!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_jobbenefit01!=.&Bihar==1
gen weighted_jobbenefit01_bihar=.
replace weighted_jobbenefit01_bihar=(numSCST)*(66/328.0002)*(ave_jobbenefit01) if scst_reserved_current==1&ave_jobbenefit01!=.&Bihar==1
replace weighted_jobbenefit01_bihar=(numSCST)*(66/314.0016)*(ave_jobbenefit01) if scst_reserved_current==0&ave_jobbenefit01!=.&Bihar==1
ttest weighted_jobbenefit01_bihar, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_MGNREGAben!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_MGNREGAben!=.&Bihar==1
gen weighted_MGNREGAben_bihar=.
replace weighted_MGNREGAben_bihar=(numSCST)*(66/328.0002)*(ave_MGNREGAben) if scst_reserved_current==1&ave_MGNREGAben!=.&Bihar==1
replace weighted_MGNREGAben_bihar=(numSCST)*(66/314.0016)*(ave_MGNREGAben) if scst_reserved_current==0&ave_MGNREGAben!=.&Bihar==1
ttest weighted_MGNREGAben_bihar, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_benefit_any!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_benefit_any!=.&Bihar==1
gen weighted_benefit_any_bihar=.
replace weighted_benefit_any_bihar=(numSCST)*(66/328.0002)*(ave_benefit_any) if scst_reserved_current==1&ave_benefit_any!=.&Bihar==1
replace weighted_benefit_any_bihar=(numSCST)*(66/314.0016)*(ave_benefit_any) if scst_reserved_current==0&ave_benefit_any!=.&Bihar==1
ttest weighted_benefit_any_bihar, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_effective!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_scst_effective!=.&Bihar==1
gen weighted_scst_effective_bihar=.
replace weighted_scst_effective_bihar=(numSCST)*(66/328.0002)*(ave_scst_effective) if scst_reserved_current==1&ave_scst_effective!=.&Bihar==1
replace weighted_scst_effective_bihar=(numSCST)*(66/314.0016)*(ave_scst_effective) if scst_reserved_current==0&ave_scst_effective!=.&Bihar==1
ttest weighted_scst_effective_bihar, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_influential!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_scst_influential!=.&Bihar==1
gen weighted_scst_influential_bihar=.
replace weighted_scst_influential_bihar=(numSCST)*(65/327.015)*(ave_scst_influential) if scst_reserved_current==1&ave_scst_influential!=.&Bihar==1
replace weighted_scst_influential_bihar=(numSCST)*(66/314.0016)*(ave_scst_influential) if scst_reserved_current==0&ave_scst_influential!=.&Bihar==1
ttest weighted_scst_influential_bihar, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_scst_priority!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_scst_priority!=.&Bihar==1
gen weighted_scst_priority_bihar=.
replace weighted_scst_priority_bihar=(numSCST)*(65/327.015)*(ave_scst_priority) if scst_reserved_current==1&ave_scst_priority!=.&Bihar==1
replace weighted_scst_priority_bihar=(numSCST)*(66/314.0016)*(ave_scst_priority) if scst_reserved_current==0&ave_scst_priority!=.&Bihar==1
ttest weighted_scst_priority_bihar, by(scst_reserved_current) unequal

sum numSCST if scst_reserved_current==1&ave_samepriority!=.&Bihar==1
sum numSCST if scst_reserved_current==0&ave_samepriority!=.&Bihar==1
gen weighted_samepriority_bihar=.
replace weighted_samepriority_bihar=(numSCST)*(66/328.0002)*(ave_samepriority) if scst_reserved_current==1&ave_samepriority!=.&Bihar==1
replace weighted_samepriority_bihar=(numSCST)*(65/310.999)*(ave_samepriority) if scst_reserved_current==0&ave_samepriority!=.&Bihar==1
ttest weighted_samepriority_bihar, by(scst_reserved_current) unequal

clear

* MEMBERS/PRESIDENTS (Table A11, continued)
use "Sarpanch_Karnataka Bihar Rajasthan merged_cluster mean level.dta"

* Karnataka
ttest scst_needseffectivektka_mean if scstrespondent==1, by(scst_reserved_current) unequal
ttest scstinfluence_mean if Karnataka==1, by(scst_reserved_current) unequal
ttest scstpriority_mean if Karnataka==1, by(scst_reserved_current) unequal
ttest samepriority_mean if Karnataka==1, by(scst_reserved_current) unequal
* note samepriority_mean is defined using only SCST respondents?  need to recode to check
*Rajasthan
ttest scstinfluence_mean if Rajasthan==1, by(scst_reserved_current) unequal
ttest scstpriority_mean if Rajasthan==1, by(scst_reserved_current) unequal
ttest samepriority_mean if Rajasthan==1, by(scst_reserved_current) unequal
*Bihar
ttest scstinfluence_mean if Bihar==1, by(scst_reserved_current) unequal
ttest scstpriority_mean if Bihar==1, by(scst_reserved_current) unequal
ttest samepriority_mean if Bihar==1, by(scst_reserved_current) unequal

clear

********* TABLE A12:  UNWEIGHTED CLUSTER MEANS, CITIZENS ANALYSIS

use "CLUSTER_MEANS_citizen_Karnataka_Bihar_Rajasthan_merged.dta"

* Now we do t-tests, using the unweighted cluster averages

* Pooled 
ttest ave_jobbenefit01, by(scst_reserved_current) unequal
ttest ave_MGNREGAben, by(scst_reserved_current) unequal
ttest ave_benefit_any, by(scst_reserved_current) unequal
ttest ave_scst_effective, by(scst_reserved_current) unequal
ttest ave_scst_influential, by(scst_reserved_current) unequal
ttest ave_scst_priority, by(scst_reserved_current) unequal
ttest ave_samepriority, by(scst_reserved_current) unequal

*Karnataka
ttest ave_jobbenefit01 if Karnataka==1, by(scst_reserved_current) unequal
ttest ave_scst_effective if Karnataka==1, by(scst_reserved_current) unequal
ttest ave_scst_influential if Karnataka==1, by(scst_reserved_current) unequal
ttest ave_scst_priority if Karnataka==1, by(scst_reserved_current) unequal

*Rajasthan
ttest ave_jobbenefit01 if Rajasthan==1, by(scst_reserved_current) unequal
ttest ave_MGNREGAben if Rajasthan==1, by(scst_reserved_current) unequal
ttest ave_benefit_any if Rajasthan==1, by(scst_reserved_current) unequal
ttest ave_scst_effective if Rajasthan==1, by(scst_reserved_current) unequal
ttest ave_scst_influential if Rajasthan==1, by(scst_reserved_current) unequal
ttest ave_scst_priority if Rajasthan==1, by(scst_reserved_current) unequal
ttest ave_samepriority if Rajasthan==1, by(scst_reserved_current) unequal

*Bihar
ttest ave_jobbenefit01 if Bihar==1, by(scst_reserved_current) unequal
ttest ave_MGNREGAben if Bihar==1, by(scst_reserved_current) unequal
ttest ave_benefit_any if Bihar==1, by(scst_reserved_current) unequal
ttest ave_scst_effective if Bihar==1, by(scst_reserved_current) unequal
ttest ave_scst_influential if Bihar==1, by(scst_reserved_current) unequal
ttest ave_scst_priority if Bihar==1, by(scst_reserved_current) unequal
ttest ave_samepriority if Bihar==1, by(scst_reserved_current) unequal

clear

********** TABLE A13: Regressions on individual-level data with clustered standard errors

use "citizen_Karnataka_Bihar_Rajasthan_merged.dta"

regress jobbenefit0_1 scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)
regress MGNREGAben scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)
regress benefit_any scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)
regress scst_effective scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)
regress scst_influential scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)

* Karnataka

regress jobbenefit0_1 scst_reserved_current if scstrespondent==1&Karnataka==1, vce(cluster Panchayat_code)
regress scst_effective scst_reserved_current if scstrespondent==1&Karnataka==1, vce(cluster Panchayat_code)
regress scst_influential scst_reserved_current if scstrespondent==1&Karnataka==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if scstrespondent==1&Karnataka==1, vce(cluster Panchayat_code)

* Rajasthan

regress jobbenefit0_1 scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)
regress MGNREGAben scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)
regress benefit_any scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)
regress scst_effective scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)
regress scst_influential scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current if scstrespondent==1&Rajasthan==1, vce(cluster Panchayat_code)

* Bihar

regress jobbenefit0_1 scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)
regress MGNREGAben scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)
regress benefit_any scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)
regress scst_effective scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)
regress scst_influential scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current if scstrespondent==1&Bihar==1, vce(cluster Panchayat_code)

clear

*  MEMBERS AND PRESIDENTS regressions with clustered standard errors (Table A13 Continued)

use "Sarpanch_Karnataka_Bihar_Rajasthan_merged.dta"

* pooled
regress scst_needseffective_ktka scst_reserved_current, vce(cluster Panchayat_code)
regress scst_influence scst_reserved_current, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current if scstrespondent==1, vce(cluster Panchayat_code)

* Karnataka
regress scst_needseffective_ktka scst_reserved_current if Karnataka==1, vce(cluster Panchayat_code)
regress scst_influence scst_reserved_current if Karnataka==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if Karnataka==1, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current  if Karnataka==1&scstrespondent==1, vce(cluster Panchayat_code)

* Rajasthan
regress scst_influence scst_reserved_current if Rajasthan==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if Rajasthan==1, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current  if Rajasthan==1&scstrespondent==1, vce(cluster Panchayat_code)

* Bihar
regress scst_influence scst_reserved_current if Bihar==1, vce(cluster Panchayat_code)
regress scst_priority scst_reserved_current if Bihar==1, vce(cluster Panchayat_code)
regress samepriority scst_reserved_current  if Bihar==1&scstrespondent==1, vce(cluster Panchayat_code)

clear

***** Table A14--Individual-level analysis without accounting for clustering

use "citizen_Karnataka_Bihar_Rajasthan_merged.dta"

ttest jobbenefit0_1 if scstrespondent==1, by(scst_reserved_current) unequal
ttest MGNREGAben if scstrespondent==1, by(scst_reserved_current) unequal
ttest benefit_any if scstrespondent==1, by(scst_reserved_current) unequal
ttest scst_effective if scstrespondent==1, by(scst_reserved_current) unequal
ttest scst_influential if scstrespondent==1, by(scst_reserved_current) unequal
ttest scst_priority if scstrespondent==1, by(scst_reserved_current) unequal
ttest samepriority if scstrespondent==1, by(scst_reserved_current) unequal

* Karnataka

ttest jobbenefit0_1 if scstrespondent==1&Karnataka==1, by(scst_reserved_current) unequal
ttest scst_effective if scstrespondent==1&Karnataka==1, by(scst_reserved_current) unequal
ttest scst_influential if scstrespondent==1&Karnataka==1, by(scst_reserved_current) unequal
ttest scst_priority if scstrespondent==1&Karnataka==1, by(scst_reserved_current) unequal

* Rajasthan

ttest jobbenefit0_1 if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal
ttest MGNREGAben if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal
ttest benefit_any if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal
ttest scst_effective if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal
ttest scst_influential if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal
ttest scst_priority if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal
ttest samepriority if scstrespondent==1&Rajasthan==1, by(scst_reserved_current) unequal

* Bihar

ttest jobbenefit0_1 if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal
ttest MGNREGAben if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal
ttest benefit_any if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal
ttest scst_effective if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal
ttest scst_influential if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal
ttest scst_priority if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal
ttest samepriority if scstrespondent==1&Bihar==1, by(scst_reserved_current) unequal

clear

* Members and presidents, unclustered analysis, pooled and by state (Table A14 continued)

use "Sarpanch_Karnataka_Bihar_Rajasthan_merged.dta"

ttest scst_needseffective_ktka if scstrespondent==1, by(scst_reserved_current) unequal
ttest scst_influence, by(scst_reserved_current) unequal
ttest scst_priority, by(scst_reserved_current) unequal
ttest samepriority if scstrespondent==1, by(scst_reserved_current) unequal
ttest samepriority if scstrespondent==1&pres==0, by(scst_reserved_current) unequal

ttest scst_needseffective_ktka if Karnataka==1&scstrespondent==1, by(scst_reserved_current) unequal
ttest scst_influence if Karnataka==1, by(scst_reserved_current) unequal
ttest scst_priority if Karnataka==1, by(scst_reserved_current) unequal
ttest samepriority if Karnataka==1&scstrespondent==1, by(scst_reserved_current) unequal
ttest samepriority if Karnataka==1&scstrespondent==1&pres==0, by(scst_reserved_current) unequal

ttest scst_influence if Rajasthan==1, by(scst_reserved_current) unequal
ttest scst_priority if Rajasthan==1, by(scst_reserved_current) unequal
ttest samepriority if Rajasthan==1&scstrespondent==1, by(scst_reserved_current) unequal
ttest samepriority if Rajasthan==1&scstrespondent==1&pres==0, by(scst_reserved_current) unequal

ttest scst_influence if Bihar==1, by(scst_reserved_current) unequal
ttest scst_priority if Bihar==1, by(scst_reserved_current) unequal
ttest samepriority if Bihar==1&scstrespondent==1, by(scst_reserved_current) unequal
ttest samepriority if Bihar==1&scstrespondent==1&pres==0, by(scst_reserved_current) unequal

clear

*** TABLE A15-- Effects of quotas for women in Rajasthan

use "citizen_Karnataka_Bihar_Rajasthan_merged.dta"

gen women_effective=.
replace women_effective=q49 if Bihar==1&q49>0&q49<8
replace women_effective=q48 if Rajasthan==1&q48>0&q48<8
label variable women_effective "The council serves the special needs of women effectively (1-7 scale)"

* First do the analysis unclustered, at the individual level  (NOTE THAT THESE TESTS ARE NOT REPORTED IN ONLINE APPENDIX)
ttest jobbenefit0_1 if (q48>0&q48<8)&sex==2, by(w_reserved_current)
ttest jobbenefit0_1 if (q48>0&q48<8)&sex==2&Rajasthan==1, by(w_reserved_current)
ttest MGNREGAben if sex==2, by(w_reserved_current)
ttest benefit_any if sex==2, by(w_reserved_current)
ttest women_effective if sex==2, by(w_reserved_current)
ttest samepriority if sex==2, by(w_reserved_current)
ttest samepriority if sex==2&Rajasthan==1, by(w_reserved_current)
ttest samepriority if sex==2&Rajasthan==1&District=="UDAIPUR", by(w_reserved_current)

clear 

* Now we aggregate to the cluster level:

use "WOMENS ANALYSIS_CLUSTER_MEANS_citizen_Karnataka_Bihar_Rajasthan_merged.dta"

drop if sex!=2

sort Panchayat_code

* the following command creates a variable with the total number of SCST respondents in each GP, which we'll use later for weighting cluster means

by Panchayat_code:egen numSCST=total(scstrespondent)

* This will sort the data by the Panchayat_code variable, which is the panchayat identifier 

* The command below returns the average income within each group and stores it in a variable called ave_income:

by Panchayat_code: egen ave_jobbenefit01_female=mean(jobbenefit0_1)
by Panchayat_code: egen ave_MGNREGAben_female=mean(MGNREGAben)
by Panchayat_code: egen ave_benefit_any_female=mean(benefit_any)
by Panchayat_code: egen ave_samepriority_female=mean(samepriority)
by Panchayat_code: egen ave_women_effective=mean(women_effective)

* Note that these variables (e.g. jobbenefit0_1) has the same value for every observation in each cluster. 

* Now, we want to drop all but the first observation in each group. The syntax is
by Panchayat_code: generate obs_num=_n
drop if obs_num~=1

ttest ave_jobbenefit01_female, by(w_reserved_current)
ttest ave_MGNREGAben_female, by(w_reserved_current)
ttest ave_benefit_any_female, by(w_reserved_current)
ttest ave_women_effective, by(w_reserved_current)
ttest ave_samepriority_female, by(w_reserved_current)
ttest ave_samepriority_female if District=="UDAIPUR", by(w_reserved_current)

* Additional tests for Uidapur district not included in Table A15:
ttest ave_jobbenefit01_female if District=="UDAIPUR", by(w_reserved_current)
ttest ave_MGNREGAben_female if District=="UDAIPUR", by(w_reserved_current)
ttest ave_benefit_any_female if District=="UDAIPUR", by(w_reserved_current)
ttest ave_women_effective if District=="UDAIPUR", by(w_reserved_current)

clear


********* Table A16: Jati and Benefit Receipt

** Karnataka

use "Karnataka_citizen_final_withpartyvars_v2.dta"

gen jatipres=.
replace jatipres=1 if s9_jati==adhyakshareportedjati&(adhyakshareportedjati>0&adhyakshareportedjati<50)
replace jatipres=0 if s9_jati!=adhyakshareportedjati&(adhyakshareportedjati>0&adhyakshareportedjati<50)
label variable jatipres "Shares caste (jati) of GP president (as per jatipres)"
ttest jobbenefit0_1, by(jatipres)
ttest jobbenefit0_1 if scstrespondent==1, by(jatipres)

clear

** Bihar

use "/Users/td244/Dropbox/Folders_New_Mac/Research/EthnicPolitics/India_panchayats/Bihar Jharkhand UP/Bihar/Bihar data/Bihar citizens_cleaned_merged with Sarpanch party_v2.dta"

* subcaste (jati) effects:
gen jatipres=.
replace jatipres=1 if q9==modepresjati&(modepresjati>0&modepresjati<50)
replace jatipres=0 if q9!=modepresjati&(modepresjati>0&modepresjati<50)
label variable jatipres "Shares caste (jati) of GP president (as per jatipres)"
ttest jobbenefit0_1, by(jatipres)
ttest jobbenefit0_1 if scstrespondent==1, by(jatipres)
ttest MGNREGAben, by(jatipres)
ttest benefit_any, by(jatipres)
ttest samepriority, by(jatipres)

clear

* Rajasthan

use "RAJASTHAN DATA CITIZEN_merged with SARPANCH party_3.dta"

* subcaste (jati) effects:
gen jatipres=.
replace jatipres=1 if q9==modepresjati&(modepresjati>0&modepresjati<50)
replace jatipres=0 if q9!=modepresjati&(modepresjati>0&modepresjati<50)
label variable jatipres "Shares caste (jati) of GP president (as per jatipres)"
gen jobbenefit0_1=0
replace jobbenefit0_1=1 if q27==1
gen MGNREGAben=0
replace MGNREGAben=1 if q24_a==1
gen benefit_any=0
replace benefit_any=1 if q23==1
ttest jobbenefit0_1, by(jatipres)
ttest jobbenefit0_1 if scstrespondent==1, by(jatipres)
ttest MGNREGAben, by(jatipres)
ttest benefit_any, by(jatipres)
ttest samepriority, by(jatipres)


**** TABLE A17 (SHARING GP PRESIDENT'S PARTY AND RECEIPT OF JOB/BENEFIT, BY STATE)

clear

use "citizen_Karnataka_Bihar_Rajasthan_merged_including census panchayat wise_TRIAL WITH SARPANCH PARTY DATA.dta"

ttest jobbenefit0_1 if Karnataka==1, by(memberpresparty)
ttest jobbenefit0_1 if Rajasthan==1, by(memberpresparty)
ttest jobbenefit0_1 if Bihar==1, by(memberpresparty)

** SC/ST respondents only, job benefit

ttest jobbenefit0_1 if Karnataka==1&scstrespondent==1, by(memberpresparty)
ttest jobbenefit0_1 if Rajasthan==1&scstrespondent==1, by(memberpresparty)
ttest jobbenefit0_1 if Bihar==1&scstrespondent==1, by(memberpresparty)

** MGNREGA benefits

ttest MGNREGAben if Rajasthan==1, by(memberpresparty)
ttest MGNREGAben if Bihar==1, by(memberpresparty)

** Any benefit 

ttest benefit_any if Rajasthan==1, by(memberpresparty)
ttest benefit_any if Bihar==1, by(memberpresparty)

** Same priority

ttest samepriority if Rajasthan==1, by(memberpresparty)
ttest samepriority if Bihar==1, by(memberpresparty)

** Job benefit by close to party

ttest jobbenefit0_1 if Karnataka==1, by(closepresparty)
ttest jobbenefit0_1 if Rajasthan==1, by(closepresparty)
ttest jobbenefit0_1 if Bihar==1, by(closepresparty)

clear














